OnRequest class

Constructors

OnRequest.delete(String path)
const
OnRequest.get(String path)
const
OnRequest.options(String path)
const
OnRequest.patch(String path)
const
OnRequest.post(String path)
const
OnRequest.put(String path)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
method → String
final
path → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited