phantom library
Classes
- DummyNodeStorage
- FileConfigJSONNodeSettings
- Firestore
- To use Firestore in your Phantom server, you need to either make sure you are running in a google cloud environment or provide a service account key file.
- Instanced
- Lifecycle
- Designates a node as a Lifecycle node, meaning it has onStart and onStop methods. If you only need light construction without futures, it's better to just use the constructor.
- Node
- NodePool
- NodeStorage
- PhantomServer
- PLogger
- ReloadableNodeStorage
- Stateful
- Designates a node as Stateful, meaning it can save and load its state. You are responsible for implementing load / save state methods.
- Tag
- Ticked
- Repeatedly calls onTick on the node
- Trait
Extensions
- XLifecycle on Lifecycle
- XLock on Lock
- XStateful on Stateful